@@ -38,13 +38,21 @@ NetStatPrivate::NetStatPrivate(NetStat *parent)
     connect(mTimer, SIGNAL(timeout()), SLOT(timeout()));
 
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+    QStringList rows(readAllFile("/proc/net/dev").split(QLatin1Char('\n'), Qt::SkipEmptyParts));
+#else
     QStringList rows(readAllFile("/proc/net/dev").split(QLatin1Char('\n'), QString::SkipEmptyParts));
+#endif
 
     rows.erase(rows.begin(), rows.begin() + 2);
 
     for (const QString &row : qAsConst(rows))
     {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        QStringList tokens = row.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#else
         QStringList tokens = row.split(QLatin1Char(':'), QString::SkipEmptyParts);
+#endif
         if (tokens.size() != 2)
             continue;
 
@@ -52,13 +60,15 @@ NetStatPrivate::NetStatPrivate(NetStat *parent)
     }
 }
 
-NetStatPrivate::~NetStatPrivate()
-{
-}
+NetStatPrivate::~NetStatPrivate() = default;
 
 void NetStatPrivate::timeout()
 {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+    QStringList rows(readAllFile("/proc/net/dev").split(QLatin1Char('\n'), Qt::SkipEmptyParts));
+#else
     QStringList rows(readAllFile("/proc/net/dev").split(QLatin1Char('\n'), QString::SkipEmptyParts));
+#endif
 
 
     if (rows.size() < 2)
@@ -67,8 +77,13 @@ void NetStatPrivate::timeout()
     QStringList names = rows[1].split(QLatin1Char('|'));
     if (names.size() != 3)
         return;
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+    QStringList namesR = names[1].split(QLatin1Char(' '), Qt::SkipEmptyParts);
+    QStringList namesT = names[2].split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#else
     QStringList namesR = names[1].split(QLatin1Char(' '), QString::SkipEmptyParts);
     QStringList namesT = names[2].split(QLatin1Char(' '), QString::SkipEmptyParts);
+#endif
     int receivedIndex    =                 namesR.indexOf(QLatin1String("bytes"));
     int transmittedIndex = namesR.size() + namesT.indexOf(QLatin1String("bytes"));
 
@@ -76,13 +91,21 @@ void NetStatPrivate::timeout()
 
     for (const QString &row : qAsConst(rows))
     {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        QStringList tokens = row.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#else
         QStringList tokens = row.split(QLatin1Char(':'), QString::SkipEmptyParts);
+#endif
         if (tokens.size() != 2)
             continue;
 
         QString interfaceName = tokens[0].trimmed();
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        QStringList data = tokens[1].split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#else
         QStringList data = tokens[1].split(QLatin1Char(' '), QString::SkipEmptyParts);
+#endif
         if (data.size() < transmittedIndex)
             continue;
 
@@ -121,8 +144,6 @@ NetStat::NetStat(QObject *parent)
     connect(impl, SIGNAL(update(unsigned,unsigned)), this, SIGNAL(update(unsigned,unsigned)));
 }
 
-NetStat::~NetStat()
-{
-}
+NetStat::~NetStat() = default;
 
 }
